# XulbuX

`XulbuX` is a library which includes a lot of small but really helpful functions.
For the libraries latest changes, see the [change log](CHANGELOG.md) (*may not work on the website*)

---

```python
import XulbuX as xx
```
The library `XulbuX` contains the following modules:
```python
  • CUSTOM TYPES:
     • rgb(int,int,int,float)
     • hsl(int,int,int,float)
     • hexa(str)
  • DIRECTORY OPERATIONS     xx.Dir
  • FILE OPERATIONS          xx.File
  • JSON FILE OPERATIONS     xx.Json
  • SYSTEM ACTIONS           xx.System
  • MANAGE ENVIRONMENT VARS  xx.Env_vars
  • CMD LOG AND ACTIONS      xx.Cmd
  • PRETTY PRINTING          xx.FormatCodes
  • COLOR OPERATIONS         xx.Color
  • DATA OPERATIONS          xx.Data
  • STR OPERATIONS           xx.String
  • CODE STRING OPERATIONS   xx.Code
  • REGEX PATTERN TEMPLATES  xx.Regex
```